==> dps-data-model-0.0.18-sources.jar: pl/topteam/dps/model/main_gen/OsobaAdresKey.java <==
package pl.topteam.dps.model.main_gen;

import net.karneim.pojobuilder.GeneratePojoBuilder;

import pl.topteam.dps.generic.GenericDPSObject;

@GeneratePojoBuilder
public class OsobaAdresKey extends GenericDPSObject {
    /**
     * OSOBA_ADRES.OSOBA_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long osobaId;

    /**
     * OSOBA_ADRES.ADRES_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long adresId;

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return OSOBA_ADRES.OSOBA_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getOsobaId() {
        return osobaId;
    }

	/**
	 * @return
	 * @mbggenerated 2014-03-10 10:45:41
	 */
	@Override
	public Long getId() {
		return -1L;
	}

    /**
     * OSOBA_ADRES.OSOBA_ID
     *
     * @param osobaId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setOsobaId(Long osobaId) {
        this.osobaId = osobaId;
    }

    /**
     * @return OSOBA_ADRES.ADRES_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getAdresId() {
        return adresId;
    }

    /**
     * OSOBA_ADRES.ADRES_ID
     *
     * @param adresId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setAdresId(Long adresId) {
        this.adresId = adresId;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        OsobaAdresKey other = (OsobaAdresKey) that;
        return (this.getOsobaId() == null ? other.getOsobaId() == null : this.getOsobaId().equals(other.getOsobaId()))
            && (this.getAdresId() == null ? other.getAdresId() == null : this.getAdresId().equals(other.getAdresId()));
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getOsobaId() == null) ? 0 : getOsobaId().hashCode());
        result = prime * result + ((getAdresId() == null) ? 0 : getAdresId().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", osobaId=").append(osobaId);
        sb.append(", adresId=").append(adresId);
        sb.append("]");
        return sb.toString();
    }
}

==> dps-data-model-0.0.23-sources.jar: pl/topteam/dps/model/main_gen/OsobaAdresKey.java <==
package pl.topteam.dps.model.main_gen;

import net.karneim.pojobuilder.GeneratePojoBuilder;

import pl.topteam.dps.model.main_gen.GenericDPSObject;

@GeneratePojoBuilder
public class OsobaAdresKey extends GenericDPSObject {
    /**
     * OSOBA_ADRES.OSOBA_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long osobaId;

    /**
     * OSOBA_ADRES.ADRES_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long adresId;

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return OSOBA_ADRES.OSOBA_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getOsobaId() {
        return osobaId;
    }

	/**
	 * @return
	 * @mbggenerated 2014-03-13 16:02:45
	 */
	@Override
	public Long getId() {
		return -1L;
	}

    /**
     * OSOBA_ADRES.OSOBA_ID
     *
     * @param osobaId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setOsobaId(Long osobaId) {
        this.osobaId = osobaId;
    }

    /**
     * @return OSOBA_ADRES.ADRES_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getAdresId() {
        return adresId;
    }

    /**
     * OSOBA_ADRES.ADRES_ID
     *
     * @param adresId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setAdresId(Long adresId) {
        this.adresId = adresId;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        OsobaAdresKey other = (OsobaAdresKey) that;
        return (this.getOsobaId() == null ? other.getOsobaId() == null : this.getOsobaId().equals(other.getOsobaId()))
            && (this.getAdresId() == null ? other.getAdresId() == null : this.getAdresId().equals(other.getAdresId()));
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getOsobaId() == null) ? 0 : getOsobaId().hashCode());
        result = prime * result + ((getAdresId() == null) ? 0 : getAdresId().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", osobaId=").append(osobaId);
        sb.append(", adresId=").append(adresId);
        sb.append("]");
        return sb.toString();
    }
}
